@@ -6,7 +6,7 @@ use strict;
 use warnings 'all';
 
 package BZ::Client::API;
-$BZ::Client::API::VERSION = '2.0_1';
+$BZ::Client::API::VERSION = '2.0_3';
 sub api_call {
     my($class, $client, $methodName, $params) = @_;
     return $client->api_call($methodName, $params)
@@ -17,6 +17,13 @@ sub error {
     return $client->error($message, $http_code, $xmlrpc_code)
 }
 
+sub new {
+    my $class = shift;
+    my $self = { @_ };
+    bless($self, ref($class) || $class);
+    return $self
+}
+
 1;
 
 __END__
@@ -31,7 +38,7 @@ BZ::Client::API - Abstract base class for the clients of the Bugzilla API.
 
 =head1 VERSION
 
-version 2.0_1
+version 2.0_3
 
 =head1 SYNOPSIS
 
