@@ -6,14 +6,14 @@ use strict;
 use warnings 'all';
 
 package BZ::Client::Bug;
-$BZ::Client::Bug::VERSION = '2.0_1';
-use BZ::Client::API;
+$BZ::Client::Bug::VERSION = '2.0_3';
+use parent qw( BZ::Client::API );
 
-our @ISA = qw(BZ::Client::API);
-
-# See https://www.bugzilla.org/docs/4.4/en/html/api/Bugzilla/WebService/Bug.html
+# See https://www.bugzilla.org/docs/tip/en/html/api/Bugzilla/WebService/Bug.html
 # These are in order as per the above
 
+## functions
+
 sub fields {
     my($class, $client, $params) = @_;
     $client->log('debug', 'BZ::Client::Bug::fields: Retrieving');
@@ -28,7 +28,7 @@ sub fields {
 
 sub legal_values {
     my($class, $client, $field) = @_;
-    $client->log('debug', "BZ::Client::Bug::legal_values: Asking for $field");
+    $client->log('debug', __PACKAGE__ . "::legal_values: Asking for $field");
     my $params = { 'field' => $field };
     my $result = $class->api_call($client, 'Bug.legal_values', $params);
     my $values = $result->{'values'};
@@ -40,7 +40,7 @@ sub legal_values {
 }
 
 sub get {
-    my($class, $client, $ids, $params) = @_;
+    my($class, $client, $params) = @_;
     $client->log('debug', 'BZ::Client::Bug::get: Asking');
     $params->{'permissive'} = BZ::Client::XMLRPC::boolean::TRUE()
         if $params->{'permissive'};
@@ -57,9 +57,37 @@ sub get {
     return wantarray ? @result : \@result
 }
 
+sub history {
+    my($class, $client, $params) = @_;
+    $client->log('debug', 'BZ::Client::Bug::history: Retrieving');
+    my $result = $class->api_call($client, 'Bug.history', $params);
+    my $bugs = $result->{'bugs'};
+    if (!$bugs || 'ARRAY' ne ref($bugs)) {
+        $class->error($client, 'Invalid reply by server, expected array of bug changes.');
+    }
+    $client->log('debug', 'BZ::Client::Bug::history: Got ' . scalar @$bugs);
+    return wantarray ? @$bugs : $bugs
+}
+
+sub possible_duplicates {
+    my($class, $client, $params) = @_;
+    $client->log('debug', __PACKAGE__ . '::possible_duplicates: Asking');
+    my $result = $class->api_call($client, 'Bug.possible_duplicates', $params);
+    my $bugs = $result->{'bugs'};
+    if (!$bugs  ||  'ARRAY' ne ref($bugs)) {
+        $class->error($client, 'Invalid reply by server, expected array of bugs.');
+    }
+    my @result;
+    for my $bug (@$bugs) {
+        push(@result, __PACKAGE__->new(%$bug));
+    }
+    $client->log('debug', __PACKAGE__ . '::possible_duplicates: Got ' . scalar(@result));
+    return wantarray ? @result : \@result
+}
+
 sub search {
     my($class, $client, $params) = @_;
-    $client->log('debug', 'BZ::Client::Bug::search: Searching');
+    $client->log('debug', __PACKAGE__ . '::search: Searching');
     my $result = $class->api_call($client, 'Bug.search', $params);
     my $bugs = $result->{'bugs'};
     if (!$bugs || 'ARRAY' ne ref($bugs)) {
@@ -67,15 +95,15 @@ sub search {
     }
     my @result;
     for my $bug (@$bugs) {
-        push(@result, BZ::Client::Bug->new(%$bug));
+        push(@result, __PACKAGE__->new(%$bug));
     }
-    $client->log('debug', 'BZ::Client::Bug::search: Found ' . join(',',@result));
+    $client->log('debug', __PACKAGE__ . '::search: Found ' . join(',',@result));
     return wantarray ? @result : \@result
 }
 
 sub create {
     my($class, $client, $params) = @_;
-    $client->log('debug', 'BZ::Client::Bug::create: Creating');
+    $client->log('debug', __PACKAGE__ . '::create: Creating');
     my $result = $class->api_call($client, 'Bug.create', $params);
     my $id = $result->{'id'};
     if (!$id) {
@@ -86,7 +114,7 @@ sub create {
 
 sub update {
     my($class, $client, $params) = @_;
-    $client->log('debug', 'BZ::Client::Bug::update: Updating');
+    $client->log('debug', __PACKAGE__ . '::update: Updating');
     my $result = $class->api_call($client, 'Bug.update', $params);
     my $bugs = $result->{'bugs'};
     if (!$bugs || 'ARRAY' ne ref($bugs)) {
@@ -97,7 +125,7 @@ sub update {
 
 sub update_see_also {
     my($class, $client, $params) = @_;
-    $client->log('debug', 'BZ::Client::Bug::update_see_also: Updating See-Also');
+    $client->log('debug', __PACKAGE__ . '::update_see_also: Updating See-Also');
     my $result = $class->api_call($client, 'Bug.update_see_also', $params);
     my $changes = $result->{'changes'};
     if (!$changes || 'HASH' ne ref($changes)) {
@@ -108,7 +136,7 @@ sub update_see_also {
 
 sub update_tags {
     my($class, $client, $params) = @_;
-    $client->log('debug', 'BZ::Client::Bug::update_tags: Updating Tags');
+    $client->log('debug', __PACKAGE__ . '::update_tags: Updating Tags');
     my $result = $class->api_call($client, 'Bug.update_tags', $params);
     my $changes = $result->{'changes'};
     if (!$changes || 'HASH' ne ref($changes)) {
@@ -117,12 +145,7 @@ sub update_tags {
     return wantarray ? %$changes : $changes
 }
 
-sub new {
-    my $class = shift;
-    my $self = { @_ };
-    bless($self, ref($class) || $class);
-    return $self
-}
+## methods
 
 sub id {
     my $self = shift;
@@ -137,9 +160,29 @@ sub id {
 sub alias {
     my $self = shift;
     if (@_) {
-        $self->{'alias'} = shift;
+        my $alias = shift;
+        if (ref $alias eq 'ARRAY' && @$a) {
+            $self->{'alias'} = $alias->[0];
+        }
+        if (not ref $alias) {
+            $self->{'alias'} = $alias;
+        }
+        # silently ignore anything else
     }
     else {
+
+        return '' unless defined $self->{'alias'};
+
+        # long form so its clear what is going on.
+        if (ref $self->{'alias'}) {
+            if (ref $self->{'alias'} eq 'ARRAY'
+                and @{$self->{'alias'}}) {
+                return $self->{'alias'}->[0];
+            }
+            return ''
+        }
+
+        # fall back
         return $self->{'alias'}
     }
 }
@@ -288,7 +331,7 @@ BZ::Client::Bug - Client side representation of a bug in Bugzilla
 
 =head1 VERSION
 
-version 2.0_1
+version 2.0_3
 
 =head1 SYNOPSIS
 
@@ -600,9 +643,125 @@ Returns an array or arrayref of bug instance objects with the given ID's.
 
 See L<INSTANCE METHODS> for how to use them.
 
+=head2 history
+
+  $history = BZ::Client::Bug->history( $client, \%params );
+  @history = BZ::Client::Bug->history( $client, \%params );
+
+Gets the history of changes for particular bugs in the database.
+
+Added in Bugzilla 3.4.
+
+=head3 Parameters
+
+=over 4
+
+=item ids
+
+An array of numbers and strings.
+
+If an element in the array is entirely numeric, it represents a bug_id from the Bugzilla database to fetch. If it contains any non-numeric characters, it is considered to be a bug alias instead, and the data bug with that alias will be loaded.
+
+=back
+
+=head3 Returns
+
+An array or arrayref of hashes, containing the following keys:
+
+=over 4
+
+=item id
+
+I<id> (int) The numeric id of the bug
+
+=item alias
+
+I<alias> (array) The alias of this bug. If there is no alias, this will be undef.
+
+=item history
+
+An array of hashes, each hash having the following keys:
+
+=over 4
+
+=item when
+
+I<when> (dateTime) The date the bug activity/change happened.
+
+=item who
+
+I<who> (string) The login name of the user who performed the bug change.
+
+=item changes
+
+An array of hashes which contain all the changes that happened to the bug at this time (as specified by when). Each hash contains the following items:
+
+=over 4
+
+=item field_name
+
+I<field_name> (string) The name of the bug field that has changed.
+
+=item removed
+
+I<removed> (string) The previous value of the bug field which has been deleted by the change.
+
+=item added
+
+I<added> (string) The new value of the bug field which has been added by the change.
+
+=item attachment_id
+
+I<attachment_id> (int) The id of the attachment that was changed. This only appears if the change was to an attachment, otherwise attachment_id will not be present in this hash.
+
+=back
+
+=back
+
+=back
+
+=head3 Errors
+
+The same as L</get>.
+
 =head2 possible_duplicates
 
-TODO
+  $bugs = BZ::Client::Bug->possible_duplicates( $client, \%params );
+  @bugs = BZ::Client::Bug->possible_duplicates( $client, \%params );
+
+Allows a user to find possible duplicate bugs based on a set of keywords such as a user may use as a bug summary. Optionally the search can be narrowed down to specific products.
+
+Added in Bugzilla 4.0.
+
+=head3 Parameters
+
+=over 4
+
+=item summary
+
+I<summary> (string) A string of keywords defining the type of bug you are trying to report. B<Required>.
+
+=item product
+
+I<product> (array) One or more product names to narrow the duplicate search to. If omitted, all bugs are searched.
+
+=back
+
+=head3 Returns
+
+The same as L</get>.
+
+Note that you will only be returned information about bugs that you can see. Bugs that you can't see will be entirely excluded from the results. So, if you want to see private bugs, you will have to first log in and then call this method.
+
+=head3 Errors
+
+=over 4
+
+=item 50 - Param Required
+
+You must specify a value for I<summary> containing a string of keywords to search for duplicates.
+
+=back
 
 =head1 FUNCTIONS FOR CREATING AND MODIFYING BUGS
 
@@ -905,7 +1064,7 @@ Gets or sets the summary of this bug.
 
 =head1 SEE ALSO
 
-  L<BZ::Client>, L<BZ::Client::API>, L<Bugzilla API|https://www.bugzilla.org/docs/4.4/en/html/api/Bugzilla/WebService/Bug.html>
+  L<BZ::Client>, L<BZ::Client::API>, L<Bugzilla API|https://www.bugzilla.org/docs/tip/en/html/api/Bugzilla/WebService/Bug.html>
 
 =head1 AUTHORS
 
