@@ -6,10 +6,10 @@ use strict;
 use warnings 'all';
 
 package BZ::Client::Bugzilla;
-$BZ::Client::Bugzilla::VERSION = '2.0_1';
-use BZ::Client::API;
+$BZ::Client::Bugzilla::VERSION = '2.0_3';
+use parent qw( BZ::Client::API );
 
-our @ISA = qw(BZ::Client::API);
+## functions
 
 sub extensions {
     my($class, $client) = @_;
@@ -18,25 +18,25 @@ sub extensions {
 
 sub time {
     my($class, $client) = @_;
-    $client->log('debug', 'BZ::Client::Bugzilla::time: Asking');
+    $client->log('debug', __PACKAGE__ . '::time: Asking');
     my $time = $class->api_call($client, 'Bugzilla.time');
-    $client->log('debug', 'BZ::Client::Bugzilla::time: Got $time');
+    $client->log('debug', __PACKAGE__ . '::time: Got $time');
     return $time
 }
 
 sub timezone {
     my($class, $client) = @_;
-    $client->log('debug', 'BZ::Client::Bugzilla::timezone: Asking');
+    $client->log('debug', __PACKAGE__ . '::timezone: Asking');
     my $timezone = $class->api_call($client, 'Bugzilla.timezone');
-    $client->log('debug', 'BZ::Client::Bugzilla::time: Got $timezone');
+    $client->log('debug', __PACKAGE__ . '::time: Got $timezone');
     return $timezone
 }
 
 sub version {
     my($class, $client) = @_;
-    $client->log('debug', 'BZ::Client::Bugzilla::version: Asking');
+    $client->log('debug', __PACKAGE__ . '::version: Asking');
     my $version = $class->api_call($client, 'Bugzilla.version');
-    $client->log('debug', 'BZ::Client::Bugzilla::time: Got $version');
+    $client->log('debug', __PACKAGE__ . '::time: Got $version');
     return $version
 }
 
@@ -54,7 +54,7 @@ BZ::Client::Bugzilla - Information about the Bugzilla server, i.e. the Bugzilla:
 
 =head1 VERSION
 
-version 2.0_1
+version 2.0_3
 
 =head1 SYNOPSIS
 
@@ -115,7 +115,7 @@ Returns the Bugzilla servers version.
 
 =head1 SEE ALSO
 
-  L<BZ::Client>, L<BZ::Client::API>, L<Bugzilla API|https://www.bugzilla.org/docs/4.4/en/html/api/Bugzilla/WebService/Bugzilla.html>
+  L<BZ::Client>, L<BZ::Client::API>, L<Bugzilla API|https://www.bugzilla.org/docs/tip/en/html/api/Bugzilla/WebService/Bugzilla.html>
 
 =head1 AUTHORS
 
