@@ -6,34 +6,34 @@ use strict;
 use warnings 'all';
 
 package BZ::Client::Product;
-$BZ::Client::Product::VERSION = '2.0_1';
-use BZ::Client::API;
+$BZ::Client::Product::VERSION = '2.0_3';
+use parent qw( BZ::Client::API );
 
-our @ISA = qw(BZ::Client::API);
+# See https://www.bugzilla.org/docs/tip/en/html/api/Bugzilla/WebService/Product.html
 
-# See https://www.bugzilla.org/docs/4.4/en/html/api/Bugzilla/WebService/Product.html
+## functions
 
 sub get_selectable_products {
     my($class, $client) = @_;
-    $client->log('debug', 'BZ::Client::Product::get_selectable_products: Asking');
+    $client->log('debug', __PACKAGE__ . '::get_selectable_products: Asking');
     my $result = $class->get_list('Product.get_selectable_products', $client);
-    $client->log('debug', 'BZ::Client::Product::get_selectable_products: Got ' . @$result);
+    $client->log('debug', __PACKAGE__ . '::get_selectable_products: Got ' . @$result);
     return $result
 }
 
 sub get_enterable_products {
     my($class, $client) = @_;
-    $client->log('debug', 'BZ::Client::Product::get_enterable_products: Asking');
+    $client->log('debug', __PACKAGE__ . '::get_enterable_products: Asking');
     my $result = $class->get_list('Product.get_enterable_products', $client);
-    $client->log('debug', 'BZ::Client::Product::get_enterable_products: Got ' . @$result);
+    $client->log('debug', __PACKAGE__ . '::get_enterable_products: Got ' . @$result);
     return $result
 }
 
 sub get_accessible_products {
     my($class, $client) = @_;
-    $client->log('debug', 'BZ::Client::Product::get_accessible_products: Asking');
-    my $result = $class->get_list("Product.get_accessible_products", $client);
-    $client->log('debug', 'BZ::Client::Product::get_accessible_products: Got ' . @$result);
+    $client->log('debug', __PACKAGE__ . '::get_accessible_products: Asking');
+    my $result = $class->get_list('Product.get_accessible_products', $client);
+    $client->log('debug', __PACKAGE__ . '::get_accessible_products: Got ' . @$result);
     return $result
 }
 
@@ -64,12 +64,7 @@ sub get {
     return \@result
 }
 
-sub new {
-    my $class = shift;
-    my $self = { @_ };
-    bless($self, ref($class) || $class);
-    return $self
-}
+## methods
 
 sub id {
     my $self = shift;
@@ -121,7 +116,7 @@ BZ::Client::Product - Client side representation of a product in Bugzilla
 
 =head1 VERSION
 
-version 2.0_1
+version 2.0_3
 
 =head1 SYNOPSIS
 
@@ -199,7 +194,7 @@ Gets or sets the products description.
 
 =head1 SEE ALSO
 
-  L<BZ::Client>, L<BZ::Client::API>, L<Bugzilla API|https://www.bugzilla.org/docs/4.4/en/html/api/Bugzilla/WebService/Product.html>
+  L<BZ::Client>, L<BZ::Client::API>, L<Bugzilla API|https://www.bugzilla.org/docs/tip/en/html/api/Bugzilla/WebService/Product.html>
 
 =head1 AUTHORS
 
