@@ -6,25 +6,25 @@ use strict;
 use warnings 'all';
 
 package BZ::Client::User;
-$BZ::Client::User::VERSION = '2.0_1';
-use BZ::Client::API;
+$BZ::Client::User::VERSION = '2.0_3';
+use parent qw( BZ::Client::API );
 
-our @ISA = qw(BZ::Client::API);
+# See https://www.bugzilla.org/docs/tip/en/html/api/Bugzilla/WebService/User.html
 
-# See https://www.bugzilla.org/docs/4.4/en/html/api/Bugzilla/WebService/User.html
+## functions
 
 sub offer_account_by_email {
     my($class, $client, $params) = @_;
     unless (ref $params) {
         $params = { email => $params }
     }
-    $client->log('debug', 'BZ::Client::User::offer_account_by_email: Inviting');
+    $client->log('debug', __PACKAGE__ . '::offer_account_by_email: Inviting');
     return $class->api_call($client, 'User.offer_account_by_email', $params);
 }
 
 sub get {
     my($class, $client, $params) = @_;
-    $client->log('debug', 'BZ::Client::User::get: Asking for (TODO)');
+    $client->log('debug', __PACKAGE__ . '::get: Asking for (TODO)');
     if ($params->{'include_disabled'}) {
         $params->{'include_disabled'} = BZ::Client::XMLRPC::boolean::TRUE()
     }
@@ -38,22 +38,17 @@ sub get {
     }
     my @result;
     for my $user (@$users) {
-        push(@result, BZ::Client::User->new(%$user));
+        push(@result, __PACKAGE__->new(%$user));
     }
-    $client->log('debug', 'BZ::Client::User::get: Got ' . scalar(@result));
+    $client->log('debug', __PACKAGE__ . '::get: Got ' . scalar(@result));
     return wantarray ? @result : \@result
 }
 
-sub new {
-    my $class = shift;
-    my $self = { @_ };
-    bless($self, ref($class) || $class);
-    return $self
-}
+## methods
 
 sub create {
     my($class, $client, $params) = @_;
-    $client->log('debug', 'BZ::Client::User::create: Creating');
+    $client->log('debug', __PACKAGE__ . '::create: Creating');
     my $result = $class->api_call($client, 'User.create', $params);
     my $id = $result->{'id'};
     if (!$id) {
@@ -64,7 +59,7 @@ sub create {
 
 sub update {
     my($class, $client, $params) = @_;
-    $client->log('debug', 'BZ::Client::User::update: Updating for: TODO');
+    $client->log('debug', __PACKAGE__ . '::update: Updating for: TODO');
     if (defined $params->{'email_enabled'}) {
         if ($params->{'email_enabled'}) {
             $params->{'email_enabled'} = BZ::Client::XMLRPC::boolean::TRUE()
@@ -80,9 +75,9 @@ sub update {
     }
     my @result;
     for my $user (@$users) {
-        push(@result, BZ::Client::User->new(%$user));
+        push(@result, __PACKAGE__->new(%$user));
     }
-    $client->log('debug', 'BZ::Client::User::update: Got ' . scalar(@result));
+    $client->log('debug', __PACKAGE__ . '::update: Got ' . scalar(@result));
     return wantarray ? @result : \@result
 }
 
@@ -100,7 +95,7 @@ BZ::Client::User - Creates and edits user accounts in Bugzilla
 
 =head1 VERSION
 
-version 2.0_1
+version 2.0_3
 
 =head1 SYNOPSIS
 
@@ -479,7 +474,7 @@ Logged-in users are not authorized to edit other users.
 
 =head1 SEE ALSO
 
-  L<BZ::Client>, L<BZ::Client::API>, L<Bugzilla API|https://www.bugzilla.org/docs/4.4/en/html/api/Bugzilla/WebService/User.html>
+  L<BZ::Client>, L<BZ::Client::API>, L<Bugzilla API|https://www.bugzilla.org/docs/tip/en/html/api/Bugzilla/WebService/User.html>
 
 =head1 AUTHORS
 
