@@ -6,10 +6,8 @@ use strict;
 use warnings 'all';
 
 package BZ::Client::XMLRPC::Array;
-$BZ::Client::XMLRPC::Array::VERSION = '2.0_1';
-use BZ::Client::XMLRPC::Handler;
-
-our @ISA = qw(BZ::Client::XMLRPC::Handler);
+$BZ::Client::XMLRPC::Array::VERSION = '2.0_3';
+use parent qw(BZ::Client::XMLRPC::Handler);
 
 sub init {
     my($self,$parser) = @_;
@@ -65,7 +63,7 @@ BZ::Client::XMLRPC::Array - Event handler for parsing a single XML-RPC array.
 
 =head1 VERSION
 
-version 2.0_1
+version 2.0_3
 
 =head1 AUTHORS
 
