@@ -6,8 +6,9 @@ use strict;
 use warnings 'all';
 
 package BZ::Client::XMLRPC::Parser;
-$BZ::Client::XMLRPC::Parser::VERSION = '2.0_1';
+$BZ::Client::XMLRPC::Parser::VERSION = '2.0_3';
 use BZ::Client::XMLRPC::Response;
+use BZ::Client::Exception;
 use XML::Parser ();
 
 sub new {
@@ -76,7 +77,6 @@ sub remove {
 
 sub error {
     my($self, $message) = @_;
-    require BZ::Client::Exception;
     BZ::Client::Exception->throw('message' => $message)
 }
 
@@ -105,7 +105,7 @@ BZ::Client::XMLRPC::Parser - A parser for an XML-RPC response.
 
 =head1 VERSION
 
-version 2.0_1
+version 2.0_3
 
 =head1 AUTHORS
 
