@@ -6,10 +6,8 @@ use strict;
 use warnings 'all';
 
 package BZ::Client::XMLRPC::Struct;
-$BZ::Client::XMLRPC::Struct::VERSION = '2.0_1';
-use BZ::Client::XMLRPC::Handler;
-
-our @ISA = qw(BZ::Client::XMLRPC::Handler);
+$BZ::Client::XMLRPC::Struct::VERSION = '2.0_3';
+use parent qw(BZ::Client::XMLRPC::Handler );
 
 sub init {
     my ($self, $parser) = @_;
@@ -89,7 +87,7 @@ BZ::Client::XMLRPC::Struct - Event handler for parsing a single XML-RPC struct.
 
 =head1 VERSION
 
-version 2.0_1
+version 2.0_3
 
 =head1 AUTHORS
 
